@@ -5,7 +5,7 @@ use File::Basename 'dirname';
 use Cwd 'abs_path';
 use Mojolicious::Plugin::MySQLViewerLite::Command;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 has command => sub {
   my $self = shift;
@@ -17,9 +17,11 @@ sub register {
   my $prefix = $conf->{prefix} // 'mysqlviewerlite';
   
   # Database
+  my $dbi = $conf->{dbi};
   my $connector = $conf->{connector};
   my $dbh = $conf->{dbh};
-  if ($connector) { $self->dbi->connector($connector) }
+  if ($dbi) { $self->dbi($dbi) }
+  elsif ($connector) { $self->dbi->connector($connector) }
   else { $self->dbi->dbh($dbh) }
   
   # Add template path
@@ -67,6 +69,7 @@ Mojolicious::Plugin::MySQLViewerLite - Mojolicious plugin to display MySQL datab
 =head1 SYNOPSYS
 
   # Mojolicious::Lite
+  # (dbh is a database handle already connected to the database)
   plugin 'MySQLViewerLite', dbh => $dbh;
 
   # Mojolicious
@@ -78,6 +81,16 @@ Mojolicious::Plugin::MySQLViewerLite - Mojolicious plugin to display MySQL datab
   # Prefix
   plugin 'MySQLViewerLite', dbh => $dbh, prefix => 'mysqlviewerlite2';
 
+  # Route
+  my $bridge = $app->route->under(sub {...});
+  plugin 'MySQLViewerLite', dbh => $dbh, route => $bridge;
+
+  # Using connection manager object instead of "dbh"
+  plugin 'MySQLViewerLite', connector => DBIx::Connector->connect(...);
+
+  # Using DBIx::Custom object instead of "dbh"
+  plugin 'MySQLViewerLite', dbi => DBIx::Custom->connect(...);
+
 =head1 DESCRIPTION
 
 L<Mojolicious::Plugin::MySQLViewerLite> is L<Mojolicious> plugin
@@ -112,19 +125,27 @@ Display C<primary keys>, C<null allowed columnes>, C<database engines> and C<cha
   connector => $connector
 
 Connector object such as L<DBIx::Connector> to connect to database.
+You can use this instead of C<dbh> option.
 
   my $connector = DBIx::Connector->connect(...);
 
-Connector has C<dbh> method to get database handle.
+Connector has C<dbh> method to get database handle
 
 =head2 C<dbh>
 
   dbh => $dbh
 
-Database handle object in L<DBI>.
+dbh is a L<DBI> database handle already connected to the database.
 
   my $dbh = DBI->connect(...);
 
+=head2 C<dbi>
+
+  dbi => DBIx::Custom->connect(...);
+
+L<DBIx::Custom> object.
+you can use this instead of C<dbh> option.
+
 =head2 C<prefix>
 
   prefix => 'mysqlviewerlite2'
@@ -139,7 +160,7 @@ Router, default to C<$app->routes>.
 
 It is useful when C<under> is used.
 
-  my $b = $r->under(sub { ... });
-  plugin 'MySQLViewerLite', dbh => $dbh, route => $b;
+  my $bridge = $r->under(sub {...});
+  plugin 'MySQLViewerLite', dbh => $dbh, route => $bridge;
 
 =cut
